embassy-stm32

Crates

git

Versions

stm32wl55jc-cm4

Flavors

IpccTxChannel

Struct IpccTxChannel 

pub struct IpccTxChannel<'a> { /* private fields */ }
IPCC TX Channel

Implementations

Source

impl<'a> IpccTxChannel<'a>

pub async fn send_exclusive<R>(&mut self, f: impl FnOnce() -> R) -> R

Send data to an IPCC channel, but wait until the corresponding rx channel is read before writing any data inside of the closure. The closure is called to write the data when appropriate.

pub async fn send<R>(&mut self, f: impl FnOnce() -> R) -> R

Send data to an IPCC channel. The closure is called to write the data when appropriate.

pub async fn flush(&mut self)

Wait for the tx channel to become clear