pub struct IpccTxChannel<'a> { /* private fields */ }Expand description
IPCC TX Channel
Implementations
Sourceimpl<'a> IpccTxChannel<'a>
impl<'a> IpccTxChannel<'a>
Sourcepub async fn send_exclusive<R>(&mut self, f: impl FnOnce() -> R) -> R
pub async fn send_exclusive<R>(&mut self, f: impl FnOnce() -> R) -> R
Send data to an IPCC channel, but wait until the corresponding rx channel is read before writing any data inside of the closure. The closure is called to write the data when appropriate.